;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "julia-snail" "20250910.703"
  "Julia Snail."
  '((emacs      "26.2")
    (dash       "2.16.0")
    (julia-mode "0.3")
    (s          "1.12.0")
    (spinner    "1.7.3")
    (popup      "0.5.9"))
  :url "https://github.com/gcv/julia-snail"
  :commit "7b50882f5aec33aa9c120f89c2e604f71bdd7a26"
  :revdesc "7b50882f5aec")
